@@ -1,23 +1,25 @@
-use 5.010;
+use 5.008001;
 use strict;
 use warnings;
 
 package App::mymeta_requires;
 # ABSTRACT: Extract module requirements from MYMETA files
-our $VERSION = '0.005'; # VERSION
+
+our $VERSION = '0.006';
 
 # Dependencies
-use autodie 2.00;
 use Class::Load qw/try_load_class/;
 use CPAN::Meta;
-use Log::Dispatchouli;
+use List::Util qw/max/;
 use Getopt::Lucid ':all';
-use Object::Tiny qw/opt logger/;
 use CPAN::Meta::Requirements;
 
+use Class::Tiny qw/opt/;
+
 my $opt_spec = [
   Param("file|f"),
   Switch("verbose|v"),
+  Switch("report"),
   Switch("help|h"),
   Switch("runtime|r")->default(1),
   Switch("configure|c")->default(1),
@@ -28,17 +30,9 @@ my $opt_spec = [
   Switch("suggests")->default(1),
 ];
 
-sub new {
-  my $class = shift;
-  my $self = bless {}, $class;
+sub BUILD {
+  my $self = shift;
   $self->{opt} = Getopt::Lucid->getopt($opt_spec);
-  $self->{logger} = Log::Dispatchouli->new({
-      ident => 'mymeta-requires',
-      to_stderr => 1,
-      debug => $self->opt->get_verbose,
-      log_pid => 0,
-  });
-  return $self;
 }
 
 sub run {
@@ -53,10 +47,15 @@ sub run {
   }
 
   my $mymeta = $self->load_mymeta
-    or $self->logger->log_fatal("Could not load a MYMETA file");
+    or die "Could not load a MYMETA file\n";
   my $prereqs = $self->merge_prereqs( $mymeta->effective_prereqs );
-  my @missing = $self->find_missing( $prereqs );
-  say for sort @missing;
+  if ( $self->opt->get_report ) {
+    print for $self->prereq_report( $prereqs );
+  }
+  else {
+    my @missing = $self->find_missing( $prereqs );
+    print for sort @missing;
+  }
   return 0;
 }
 
@@ -68,9 +67,9 @@ sub load_mymeta {
   for my $f ( @candidates ) {
     next unless -r $f;
     my $mymeta = eval { CPAN::Meta->load_file($f) }
-      or $self->logger->log_debug("Error loading '$f': $@");
+      or $self->_log("Error loading '$f': $@\n");
     if ( $mymeta ) {
-      $self->logger->log_debug("Got MYMETA from '$f'");
+      $self->_log("Got MYMETA from '$f'\n");
       return $mymeta;
     }
   }
@@ -101,15 +100,47 @@ sub find_missing {
   for my $mod ( $prereqs->required_modules ) {
     next if $mod eq 'perl';
     if ( try_load_class($mod) ) {
-      push @missing, $mod unless $prereqs->accepts_module($mod, $mod->VERSION);
+      push @missing, "$mod\n" unless $prereqs->accepts_module($mod, $mod->VERSION);
     }
     else {
-      push @missing, $mod;
+      push @missing, "$mod\n";
     }
   }
   return @missing;
 }
 
+sub prereq_report {
+    my ( $self, $prereqs ) = @_;
+    my @report;
+    for my $mod ( sort $prereqs->required_modules ) {
+        next if $mod eq 'perl';
+        my $req = $prereqs->requirements_for_module($mod);
+        if ( try_load_class($mod) ) {
+            my $version = $mod->VERSION || "<no version>";
+            push @report, [ $mod, $version, $req ];
+        }
+        else {
+            push @report, [ $mod, "<missing>", $req ];
+        }
+    }
+    my $max_mod_len = max( map { length $_->[0] } @report );
+    my $max_ver_len = max( map { length $_->[1] } @report );
+    my $max_req_len = max( map { length $_->[2] } @report );
+
+    unshift @report, [ "Module", "Have", "Want" ],
+      [ "-" x $max_mod_len, "-" x $max_ver_len, "-" x $max_req_len ];
+
+    return map {
+        sprintf( "%-*s %-*s %-*s\n",
+            $max_mod_len, $_->[0], $max_ver_len, $_->[1], $max_req_len, $_->[2] )
+    } @report;
+}
+
+sub _log {
+  my $self = shift;
+  warn "$_[0]\n" if $self->opt->get_verbose;
+}
+
 1;
 
 
@@ -119,7 +150,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -127,7 +158,7 @@ App::mymeta_requires - Extract module requirements from MYMETA files
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -139,12 +170,12 @@ version 0.005
 This module contains the guts of the LE<lt>mymeta_requiresE<gt> program.  See
 that program for command line usage information.
 
-=for Pod::Coverage find_missing
+=for Pod::Coverage BUILD
+find_missing
 load_mymeta
-logger
 merge_prereqs
-new
 opt
+prereq_report
 run
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
@@ -164,7 +195,7 @@ public review and contribution under the terms of the license.
 
 L<https://github.com/dagolden/app-mymeta_requires>
 
-  git clone git://github.com/dagolden/app-mymeta_requires.git
+  git clone https://github.com/dagolden/app-mymeta_requires.git
 
 =head1 AUTHOR
 
